<?php
/**
* 륤󥿥ե
*
* PHP version 5
*
* @package    interfaces
* @author     stk2k <stk2k@sazysoft.com>
* @copyright  2008 stk2k, sazysoft
*/
interface ITask extends IObject
{
	/**
	 * 
	 */
	public function init( Config $config );

	/**
	 * ɾ
	 */
	public function getGuardConditions();

	/**
	 * ٥ȥե륿
	 */
	public function getEventFilters();

	/**
	 * ݥȥ
	 */
	public function getPostActions();

	/**
	 * ٥Ȥ
	 */
	public function processEvent( IEvent $event );

}

return __FILE__;